@@ -499,18 +499,26 @@ describe("scale_xaringan_*", {
 
 })
 
-test_that("register_font() returns the name of the font family if font pkgs are missing", {
+test_that("register_font() returns the name of the font family if {showtext} is missing", {
   text_font_family <- xaringanthemer_font_default("text_font_family")
+
   family_showtext_missing <- testthat::with_mock(
     `xaringanthemer:::requires_package` = function(pkg, ...) pkg != "showtext",
     register_font(text_font_family, google = TRUE)
   )
 
   expect_equal(family_showtext_missing, text_font_family)
+})
+
+test_that("register_font() returns the name of the font family if {sysfonts} is missing", {
+  skip_if_not_installed("showtext")
+
+  text_font_family <- xaringanthemer_font_default("text_font_family")
 
   family_sysfonts_missing <- testthat::with_mock(
     `xaringanthemer:::requires_package` = function(pkg, ...) pkg != "sysfonts",
     register_font(text_font_family, google = TRUE)
   )
+
   expect_equal(family_sysfonts_missing, text_font_family)
 })
